textmining.TsujiiC3.TsujiiObject

|  | ## Cheshire3 Object Model: Class TsujiiObject

Package textmining :: Module TsujiiC3 :: Class TsujiiObject

## Class TsujiiObject
source code

Known Subclasses:
  tmTransformer.TsujiiTextPosTransformer, tmTransformer.TsujiiXPathTransformer, tmNormalizer.TsujiiPosNormalizer, tmPreParser.TsujiiTextPosPreParser, tmPreParser.TsujiiXMLPosPreParser

Instance Methods

__init__(self, session, node, parent)
tag(self, session, data, xml=0)
toxml(self, data)

Class Variables

inh |
outh |
tokenizer |

Method Details

### __init__(self, session, node, parent) (Constructor) | source code

### tag(self, session, data, xml=0) | source code

### toxml(self, data) | source code

Class Variable Details

    ### inh Value:
        None

    ### outh Value:
        None

    ### tokenizer Value:
        None